@@ -8,7 +8,7 @@ use DBD::Pg;
 
 use base qw(Alzabo::Driver);
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -109,54 +109,6 @@ sub get_last_id
     return $self->{last_id};
 }
 
-sub start_transaction
-{
-    my $self = shift;
-
-    $self->{tran_count} = 0 unless defined $self->{tran_count};
-    $self->{tran_count}++;
-
-    $self->{dbh}->{AutoCommit} = 0;
-}
-
-sub rollback
-{
-    my $self = shift;
-
-    $self->{dbh}->rollback unless $self->{dbh}->{AutoCommit};
-
-    $self->{dbh}->{AutoCommit} = 1;
-
-    $self->{tran_count} = undef;
-}
-
-sub finish_transaction
-{
-    my $self = shift;
-
-    # More commits than begin_tran.  Not correct.
-    if ( defined $self->{tran_count} )
-    {
-	$self->{tran_count}--;
-    }
-    else
-    {
-	my $callee = (caller(1))[3];
-	warn "$callee called commit without corresponding begin_tran call\n";
-    }
-
-    # Don't actually commit until we reach 'uber-commit'
-    return if $self->{tran_count};
-
-    unless ( $self->{dbh}->{AutoCommit} )
-    {
-        $self->{dbh}->commit;
-    }
-    $self->{dbh}->{AutoCommit} = 1;
-
-    $self->{tran_count} = undef;
-}
-
 sub driver_id
 {
     return 'PostgreSQL';
