@@ -15,7 +15,7 @@ Params::Validate::set_options( on_fail => sub { Alzabo::Exception::Params->throw
 use Storable ();
 use Tie::IxHash ();
 
-$VERSION = sprintf '%2d.%02d', q$Revision: 1.32 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf '%2d.%02d', q$Revision: 1.33 $ =~ /(\d+)\.(\d+)/;
 
 1;
 
@@ -141,7 +141,7 @@ sub sqlmaker
 {
     my $self = shift;
 
-    return $self->{sql};
+    return $self->{sql}->new( $self->driver );
 }
 
 __END__
